"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.listRecursive = void 0;
const logger_1 = require("@pnpm/logger");
const list_1 = require("./list");
async function listRecursive(pkgs, params, opts) {
    const depth = opts.depth ?? 0;
    if (opts.lockfileDir) {
        return (0, list_1.render)(pkgs.map((pkg) => pkg.dir), params, {
            ...opts,
            alwaysPrintRootPackage: depth === -1,
            lockfileDir: opts.lockfileDir,
        });
    }
    const outputs = (await Promise.all(pkgs.map(async ({ dir }) => {
        try {
            return await (0, list_1.render)([dir], params, {
                ...opts,
                alwaysPrintRootPackage: depth === -1,
                lockfileDir: opts.lockfileDir ?? dir,
            });
        }
        catch (err) { // eslint-disable-line
            logger_1.logger.info(err);
            err['prefix'] = dir;
            throw err;
        }
    }))).filter(Boolean);
    if (outputs.length === 0)
        return '';
    const joiner = typeof depth === 'number' && depth > -1 ? '\n\n' : '\n';
    return outputs.join(joiner);
}
exports.listRecursive = listRecursive;
//# sourceMappingURL=recursive.js.map